## ----include = FALSE----------------------------------------------------------
BiocStyle::markdown()
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----installation, eval=FALSE-------------------------------------------------
#  if (!require("devtools", quietly = TRUE))
#      install.packages("devtools")
#  devtools::install_github("TranslationalBioinformaticsUnit/ClustAll")

## ----load---------------------------------------------------------------------
library(ClustAll)

## -----------------------------------------------------------------------------
# load example data
data("BreastCancerWisconsin", package = "ClustAll") 

# remove patients ID (non-informative), and diagnosis as it is the "true label"
data_use <- subset(wdbc,select=-ID)

# explore the features of example data
str(data_use)

## -----------------------------------------------------------------------------
obj_noNA <- createClustAll(data = data_use, colValidation = "Diagnosis",
                           nImputation = NULL, dataImputed = NULL)

## -----------------------------------------------------------------------------
str(obj_noNA)

## ----results=FALSE------------------------------------------------------------
# Considering all the depths of the dendrogram, otherwise set simplify to TRUE
obj_noNA1 <- runClustAll(Object = obj_noNA, threads = 2, simplify = FALSE)

## ----results=FALSE, warning=FALSE---------------------------------------------
plotJACCARD(Object = obj_noNA1, stratification_similarity = 0.88)

## -----------------------------------------------------------------------------
resStratification(Object = obj_noNA1, population = 0.05, 
                  stratification_similarity = 0.88, all = FALSE)

## -----------------------------------------------------------------------------
plotSANKEY(Object = obj_noNA1, clusters = c("cuts_c_3","cuts_a_9"), validationData = FALSE)

plotSANKEY(Object = obj_noNA1, clusters = c("cuts_c_3","cuts_b_13"), validationData = FALSE)

plotSANKEY(Object = obj_noNA1, clusters = c("cuts_a_9"), validationData = TRUE)

## -----------------------------------------------------------------------------
df <- cluster2data(Object = obj_noNA1,
                   stratificationName = c("cuts_c_3","cuts_a_9","cuts_b_13"))

## -----------------------------------------------------------------------------
# STRATIFICATION 1
validateStratification(obj_noNA1, "cuts_a_9")

# STRATIFICATION 2
validateStratification(obj_noNA1, "cuts_b_13")

# STRATIFICATION 3
validateStratification(obj_noNA1, "cuts_b_9")

## ----results=FALSE------------------------------------------------------------
data("BreastCancerWisconsinMISSING", package = "ClustAll")
data_use_NA <- wdbcNA
colSums(is.na(data_use_NA)) # dataset present NAs

obj_NA <- createClustAll(data_use_NA, nImputation = 2,  
                         colValidation = "Diagnosis") 


## ----results=FALSE, eval=FALSE------------------------------------------------
#  obj_NA1 <- runClustAll(obj_NA, threads = 2)
#  
#  # Represent the Jaccard Distance between population-robust stratifications
#  plotJACCARD(Object = obj_NA1, stratification_similarity = 0.88)
#  
#  # Retrieve stratification representatives
#  resStratification(Object = obj_NA1, population = 0.05,
#                    stratification_similarity = 0.88, all = FALSE)
#  
#  # Generate Sankey diagrams comparing pairs of stratifications, or a stratification with true labels
#  plotSANKEY(Object = obj_NA1, clusters = c("cuts_a_2","cuts_a_8"),
#             validationData = FALSE)
#  
#  plotSANKEY(Object = obj_NA1, clusters = c("cuts_a_2"),
#             validationData = TRUE)
#  
#  # Retrieve the original dataset with the selected ClustAll stratification(s)
#  df_NA <- cluster2data(Object = obj_NA1, stratificationName = c("cuts_a_2"))
#  
#  # Assess the results the sensitivity and specifity of the selected ClustAll
#  # stratifications against true labels (if available)
#  validateStratification(obj_NA1, "cuts_a_2")

## ----results=FALSE------------------------------------------------------------
library(mice)
data("BreastCancerWisconsinMISSING", package = "ClustAll") # load example data
data_use_NA <- wdbcNA
str(data_use_NA)

imp_data_use <- mice(data_use_NA[-1], m=2, maxit = 5,seed=1234, print=FALSE)

## ----results=FALSE------------------------------------------------------------
# dataImputed contains the mids object with the imputed
obj_imp1 <- createClustAll(data=data_use_NA, dataImputed = imp_data_use, 
                           colValidation = "Diagnosis") 

## ----results=FALSE, eval=FALSE------------------------------------------------
#  # The rest of the pipeline follows as a)
#  obj_imp1 <- runClustAll(obj_imp1, threads = 2)
#  
#  # Represent the Jaccard Distance between population-robust stratifications
#  plotJACCARD(Object = obj_imp1, stratification_similarity = 0.88)
#  
#  # Retrieve stratification representatives
#  resStratification(Object = obj_imp1, population = 0.05,
#                    stratification_similarity = 0.88, all = FALSE)
#  
#  # Generate Sankey diagrams comparing pairs of stratifications, or a stratification with true labels
#  plotSANKEY(Object = obj_imp1, clusters = c("cuts_a_2","cuts_a_22"), validationData = FALSE)
#  
#  # Retrieve the original dataset with the selected ClustAll stratification(s)
#  df_imp <- cluster2data(Object = obj_imp1, stratificationName = c("cuts_a_2"))
#  
#  # Validate stratification
#  validateStratification(obj_imp1, "cuts_a_2")

## -----------------------------------------------------------------------------
sessionInfo()

